# CHANGELOG



## v0.1.0 (2024-05-12)

### Chore

* chore: fix github badge ([`1cb5552`](https://github.com/dtch1997/transcoders-slim/commit/1cb55529c49bcc19acee8df35298a18bf06937e2))

* chore: update readme, tests ([`2188dc3`](https://github.com/dtch1997/transcoders-slim/commit/2188dc36e03be98adb719bf6ace31bf789e1ad6f))

* chore: fix lint, remove pyright ([`cf0d205`](https://github.com/dtch1997/transcoders-slim/commit/cf0d205e2366dc3d6b1ece5af06ff4cacd516dad))

### Feature

* feat: bump version ([`e8d27bc`](https://github.com/dtch1997/transcoders-slim/commit/e8d27bc1ccea9a1aa8e11558b3565b77ef04ab04))

### Unknown

* add explicit map location ([`ba709e3`](https://github.com/dtch1997/transcoders-slim/commit/ba709e361465d3f91be40ace41a59cfaeb180778))

* Merge branch &#39;main&#39; of github.com:dtch1997/transcoders-slim into main ([`56322a2`](https://github.com/dtch1997/transcoders-slim/commit/56322a25ae0fc4a4bf4eb2b6eaf91a91c402271a))

* working transcoder ([`560e15c`](https://github.com/dtch1997/transcoders-slim/commit/560e15c22d739e9c35549d3b3e3c8c712d3ee913))

* add tests ([`a9d625f`](https://github.com/dtch1997/transcoders-slim/commit/a9d625f02e55fda2e1c843c3bfe911a77ec78377))

* loading working ([`1d00f3e`](https://github.com/dtch1997/transcoders-slim/commit/1d00f3eef927391c29ebcdd85fb394efed691ed8))


## v0.0.0 (2024-05-09)

### Unknown

* initial commit ([`18fdee3`](https://github.com/dtch1997/transcoders-slim/commit/18fdee3092e941d88c6b287649eb5be1ce4e5b90))
